PublishedVersionEntry

Struct PublishedVersionEntry 

pub struct PublishedVersionEntry {
    pub kind: String,
    pub generation: usize,
    pub created_at: DateTime<FixedOffset>,
    pub ref_: String,
    pub launch_measurement: LaunchMeasurement,
    pub signature: PublishedVersionEntrySignature,
}

Fields

kind: String

The kind of entry, in case we want to include other types in the future (e.g., key revocations, …)

generation: usize

How Self::launch_measurement was calculated (breaking changes increase the version)

created_at: DateTime<FixedOffset>ref_: String

Reference to the source repository as Nix flake URL

launch_measurement: LaunchMeasurement

Launch measurement for the system version. Generation 1 stores a flat SHA-384 digest; generation 2 stores the pre-VMSA digest and VMSA bytes separately to decouple the measurement from the vCPU count.

signature: PublishedVersionEntrySignature

YAXI signature

Implementations

Source

impl PublishedVersionEntry

pub fn verify_signature(&self) -> Result<(), SignatureVerificationError>

Verifies whether this entry is signed with a well-known key.

Errors

Returns an error if the key id is unknown. Also forwards errors from ed25519_dalek